==> lms-1.3.2+libs.tar.gz: lms/modules/tariffadd.php <==
<?php

/*
 * LMS version 1.3-cvs
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tariffadd.php,v 1.35 2004/03/15 13:49:02 alec Exp $
 */

$tariffadd = $_POST['tariffadd'];

if(isset($tariffadd))
{
	foreach($tariffadd as $key => $value)
		$tariffadd[$key] = trim($value);

	if($tariffadd['name']=='' && $tariffadd['comment']=='' && $tariffadd['value']=='')
	{
		header("Location: ?m=tarifflist");
		die;
	}

	$tariffadd['value'] = str_replace(',','.',$tariffadd['value']);

	if(!(ereg('^[-]?[0-9.,]+$',$tariffadd['value'])))
		$error['value'] = 'Podana warto taryfy jest niepoprawna!';

	if($tariffadd['taxvalue']=='') $tariffadd['taxvalue'] = 0;
	if(!(ereg('^[0-9.,]+$',$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
		$error['taxvalue'] = 'Podana stawka podatku jest niepoprawna!';

	if(!(ereg('^[0-9]+$', $tariffadd['uprate'])) && $tariffadd['uprate'] != '')
		$error['uprate'] = 'Pole uprate musi zawiera liczb cakowit';
	if($tariffadd['uprate']=='') $tariffadd['uprate'] = 0;
		
	if(!ereg('^[0-9]+$', $tariffadd['downrate']) && $tariffadd['downrate'] != '')
		$error['downrate'] = 'Pole downrate zawiera liczb cakowit';
	if($tariffadd['downrate']=='') $tariffadd['downrate'] = 0;
	
	if(($tariffadd['uprate'] < 8 || $tariffadd['uprate'] > 4096) && $tariffadd['uprate'] != '')
		$error['uprate'] = 'Pole uprate musi zawiera liczb z przedziau 8 - 4096';

	if(($tariffadd['downrate'] < 8 || $tariffadd['downrate'] > 4096) && $tariffadd['downrate'] != '')
		$error['downrate'] = 'Pole downrate musi zawiera liczb z przedziau 8 - 4096';
	
	if($tariffadd['name'] == '')
		$error['name'] = 'Musisz poda nazw taryfy!';
	else
		if($LMS->GetTariffIDByName($tariffadd['name']))
			$error['name'] = "Istnieje ju taryfa o nazwie '".$tariffadd['name']."'!";

	if(!$error){
		header('Location: ?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
		die;
	}
	
}

$layout['pagetitle'] = 'Nowa taryfa';

$SMARTY->assign('error',$error);
$SMARTY->assign('tariffadd',$tariffadd);
$SMARTY->display('tariffadd.html');

?>

==> lms-1.3.3+libs.tar.gz: lms/modules/tariffadd.php <==
<?php

/*
 * LMS version 1.3-cvs
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tariffadd.php,v 1.36 2004/04/07 13:41:18 chilek Exp $
 */

$tariffadd = $_POST['tariffadd'];

if(isset($tariffadd))
{
	foreach($tariffadd as $key => $value)
		$tariffadd[$key] = trim($value);

	if($tariffadd['name']=='' && $tariffadd['comment']=='' && $tariffadd['value']=='')
	{
		header("Location: ?m=tarifflist");
		die;
	}

	$tariffadd['value'] = str_replace(',','.',$tariffadd['value']);

	if(!(ereg('^[-]?[0-9.,]+$',$tariffadd['value'])))
		$error['value'] = 'Podana warto taryfy jest niepoprawna!';

	if($tariffadd['taxvalue']!='')
		if(!(ereg('^[0-9.,]+$',$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
			$error['taxvalue'] = 'Podana stawka podatku jest niepoprawna!';

	if(!(ereg('^[0-9]+$', $tariffadd['uprate'])) && $tariffadd['uprate'] != '')
		$error['uprate'] = 'Pole uprate musi zawiera liczb cakowit';
	if($tariffadd['uprate']=='') $tariffadd['uprate'] = 0;
		
	if(!ereg('^[0-9]+$', $tariffadd['downrate']) && $tariffadd['downrate'] != '')
		$error['downrate'] = 'Pole downrate zawiera liczb cakowit';
	if($tariffadd['downrate']=='') $tariffadd['downrate'] = 0;
	
	if(($tariffadd['uprate'] < 8 || $tariffadd['uprate'] > 4096) && $tariffadd['uprate'] != '')
		$error['uprate'] = 'Pole uprate musi zawiera liczb z przedziau 8 - 4096';

	if(($tariffadd['downrate'] < 8 || $tariffadd['downrate'] > 4096) && $tariffadd['downrate'] != '')
		$error['downrate'] = 'Pole downrate musi zawiera liczb z przedziau 8 - 4096';
	
	if($tariffadd['name'] == '')
		$error['name'] = 'Musisz poda nazw taryfy!';
	else
		if($LMS->GetTariffIDByName($tariffadd['name']))
			$error['name'] = "Istnieje ju taryfa o nazwie '".$tariffadd['name']."'!";

	if(!$error){
		header('Location: ?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
		die;
	}
	
}

$layout['pagetitle'] = 'Nowa taryfa';

$SMARTY->assign('error',$error);
$SMARTY->assign('tariffadd',$tariffadd);
$SMARTY->display('tariffadd.html');

?>
